import MongoConnector from "./mongo_connector";
export interface IDataLoader<S, T> {
    clear(id: string): void;
    clearAll(): void;
    load(key: string): any;
}
import { Collection, DeleteResult, Document, Filter, FindCursor, FindOptions, InsertManyResult, InsertOneResult, OptionalId, UpdateFilter, UpdateOptions, UpdateResult, WithId } from "mongodb";
export interface Options<K, V> {
    batch?: boolean;
    cache?: boolean;
    cacheKeyFn?: (key: any) => any;
    cacheMap?: Map<K, Promise<V>> | "lru";
    clearOnInsert?: boolean;
    clearOnUpdate?: boolean;
    selectorKeyFn?: (key: any) => any;
}
export declare class LruCacheWrapper<K, V> {
    cache: any;
    constructor(cacheSize?: number);
    clear(): void;
    get(key: K): any;
    set(key: K, value: V): any;
    delete(key: K): boolean;
}
export default class MongoEntity<T> {
    connector: MongoConnector;
    private _collectionName;
    private _collection;
    private _singleLoader;
    private _multiLoader;
    private _insertLoaders;
    private _updateLoaders;
    static DefaultCache: any;
    private _cache;
    get collection(): Collection<T>;
    constructor(connector: MongoConnector, collectionName: string, cache?: any);
    clearUpdateCaches(selector: any): void;
    clearInsertCaches(selector: any): void;
    assignFilter(object: Object, selector: Object, result: Object, include: 0 | 1): (k: string) => void;
    filter(object: Object, selector: Object): WithId<T>;
    find(selector: Filter<T>, options?: FindOptions): FindCursor<WithId<T>>;
    findOne(selector: Filter<T>, options?: FindOptions): Promise<WithId<T>>;
    findOneCached(loader: IDataLoader<string, T>, key: string, selector?: Object): Promise<WithId<T>>;
    findOneCachedById(id: string, selector?: Object): Promise<WithId<T>>;
    findManyCached(loader: IDataLoader<string, T[]>, key: string, selector?: Object): Promise<T[]>;
    findAllCached(selector?: Object): Promise<T[]>;
    addCacheToOptions(options: any): any;
    insertOne(document: OptionalId<T>): Promise<InsertOneResult>;
    insertMany(document: OptionalId<T>[]): Promise<InsertManyResult>;
    deleteOne(selector: Object, many?: boolean): Promise<DeleteResult>;
    deleteMany(selector: Object, many?: boolean): Promise<DeleteResult>;
    dispose(): Promise<DeleteResult>;
    updateOne(selector: Filter<T>, update: UpdateFilter<T>, options?: UpdateOptions): Promise<UpdateResult>;
    updateMany(selector: Filter<T>, update: UpdateFilter<T>, options?: UpdateOptions): Promise<Document | UpdateResult>;
    createLoader(selectorFunction: (key: any) => Promise<WithId<T>>, options?: Options<any, T | T[]>): any;
}
